from distutils.core import setup
setup(
  name = 'tuturu2',
  packages = ['tuturu2'], # this must be the same as the name above
  version = '0.6',
  description = 'A module to simplify the well know module named pickle.',
  author = 'Pickle',
  author_email = 'pickle@gmail.com',
  url = 'http://marco213.com', # use the URL to the github repo
  keywords = ['pickle', 'tuturu'], # arbitrary keywords
  classifiers = [],
)
